# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: input_file.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import contract_pb2 as contract__pb2
from fameprotobuf import field_pb2 as field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10input_file.proto\x12\x08iobinary\x1a\x0e\x63ontract.proto\x1a\x0b\x66ield.proto\"\x93\x06\n\tInputData\x12\x0e\n\x06run_id\x18\x01 \x02(\x03\x12\x37\n\nsimulation\x18\x02 \x02(\x0b\x32#.iobinary.InputData.SimulationParam\x12\x36\n\x0btime_series\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12,\n\x06\x61gents\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12/\n\tcontracts\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x12\x0e\n\x06schema\x18\x08 \x01(\t\x12\x35\n\x0bstring_sets\x18\t \x03(\x0b\x32 .iobinary.InputData.StringSetDao\x12\x10\n\x08metadata\x18\n \x01(\t\x1aM\n\x0fSimulationParam\x12\x12\n\nstart_time\x18\x01 \x02(\x03\x12\x11\n\tstop_time\x18\x02 \x02(\x03\x12\x13\n\x0brandom_seed\x18\x03 \x02(\x03\x1ai\n\rTimeSeriesDao\x12\x11\n\tseries_id\x18\x01 \x02(\x05\x12\x13\n\x0bseries_name\x18\x02 \x01(\t\x12\x16\n\ntime_steps\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x12\n\x06values\x18\x05 \x03(\x01\x42\x02\x10\x01J\x04\x08\x03\x10\x04\x1a\x63\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x12\n\nclass_name\x18\x02 \x02(\t\x12%\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x10\n\x08metadata\x18\x04 \x01(\t\x1a\xa1\x01\n\x0cStringSetDao\x12\x0c\n\x04name\x18\x01 \x02(\t\x12?\n\x06values\x18\x02 \x03(\x0b\x32/.iobinary.InputData.StringSetDao.StringSetEntry\x12\x10\n\x08metadata\x18\x03 \x01(\t\x1a\x30\n\x0eStringSetEntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08\x42$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Input')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'input_file_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Input'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['time_steps']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['time_steps']._serialized_options = b'\020\001'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_INPUTDATA']._serialized_start=60
  _globals['_INPUTDATA']._serialized_end=847
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_start=386
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_end=463
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_start=465
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_end=570
  _globals['_INPUTDATA_AGENTDAO']._serialized_start=572
  _globals['_INPUTDATA_AGENTDAO']._serialized_end=671
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_start=674
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_end=835
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_start=787
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_end=835
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contract.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import field_pb2 as field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ontract.proto\x12\rcommunication\x1a\x0b\x66ield.proto\"\xf5\x01\n\rProtoContract\x12\x11\n\tsender_id\x18\x01 \x02(\x03\x12\x13\n\x0breceiver_id\x18\x02 \x02(\x03\x12\x14\n\x0cproduct_name\x18\x03 \x02(\t\x12\x1b\n\x13\x66irst_delivery_time\x18\x04 \x02(\x03\x12\"\n\x1a\x64\x65livery_interval_in_steps\x18\x05 \x02(\x03\x12,\n\x0f\x65xpiration_time\x18\x06 \x01(\x03:\x13\x39\x32\x32\x33\x33\x37\x32\x30\x33\x36\x38\x35\x34\x37\x37\x35\x38\x30\x37\x12%\n\x06\x66ields\x18\x07 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x10\n\x08metadata\x18\x08 \x01(\tB(\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\tContracts')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'contract_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\tContracts'
  _globals['_PROTOCONTRACT']._serialized_start=47
  _globals['_PROTOCONTRACT']._serialized_end=292
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModelData(_message.Message):
    __slots__ = ("name", "version", "package_definition", "agent_classes", "metadata")
    class JavaPackages(_message.Message):
        __slots__ = ("agents", "data_items", "portables")
        AGENTS_FIELD_NUMBER: _ClassVar[int]
        DATA_ITEMS_FIELD_NUMBER: _ClassVar[int]
        PORTABLES_FIELD_NUMBER: _ClassVar[int]
        agents: _containers.RepeatedScalarFieldContainer[str]
        data_items: _containers.RepeatedScalarFieldContainer[str]
        portables: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, agents: _Optional[_Iterable[str]] = ..., data_items: _Optional[_Iterable[str]] = ..., portables: _Optional[_Iterable[str]] = ...) -> None: ...
    class AgentClass(_message.Message):
        __slots__ = ("name_alias", "import_identifier", "language", "metadata", "attributes", "products", "outputs")
        class ImplementationLanguage(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            LANGUAGE_UNSPECIFIED: _ClassVar[ModelData.AgentClass.ImplementationLanguage]
            JAVA: _ClassVar[ModelData.AgentClass.ImplementationLanguage]
            PYTHON: _ClassVar[ModelData.AgentClass.ImplementationLanguage]
        LANGUAGE_UNSPECIFIED: ModelData.AgentClass.ImplementationLanguage
        JAVA: ModelData.AgentClass.ImplementationLanguage
        PYTHON: ModelData.AgentClass.ImplementationLanguage
        class Attribute(_message.Message):
            __slots__ = ("name", "type", "is_mandatory", "is_list", "metadata", "values", "default", "nested_attributes")
            class AttributeType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
                __slots__ = ()
                ATTRIBUTE_TYPE_UNSPECIFIED: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                BOOLEAN: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                INTEGER: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                LONG: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                TIME_STAMP: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                DOUBLE: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                STRING: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                STRING_SET: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                ENUM: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                TIME_SERIES: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
                BLOCK: _ClassVar[ModelData.AgentClass.Attribute.AttributeType]
            ATTRIBUTE_TYPE_UNSPECIFIED: ModelData.AgentClass.Attribute.AttributeType
            BOOLEAN: ModelData.AgentClass.Attribute.AttributeType
            INTEGER: ModelData.AgentClass.Attribute.AttributeType
            LONG: ModelData.AgentClass.Attribute.AttributeType
            TIME_STAMP: ModelData.AgentClass.Attribute.AttributeType
            DOUBLE: ModelData.AgentClass.Attribute.AttributeType
            STRING: ModelData.AgentClass.Attribute.AttributeType
            STRING_SET: ModelData.AgentClass.Attribute.AttributeType
            ENUM: ModelData.AgentClass.Attribute.AttributeType
            TIME_SERIES: ModelData.AgentClass.Attribute.AttributeType
            BLOCK: ModelData.AgentClass.Attribute.AttributeType
            class ValueSet(_message.Message):
                __slots__ = ("metadata", "bool_values", "int_values", "long_values", "float_values", "double_values", "string_values", "byte_values")
                METADATA_FIELD_NUMBER: _ClassVar[int]
                BOOL_VALUES_FIELD_NUMBER: _ClassVar[int]
                INT_VALUES_FIELD_NUMBER: _ClassVar[int]
                LONG_VALUES_FIELD_NUMBER: _ClassVar[int]
                FLOAT_VALUES_FIELD_NUMBER: _ClassVar[int]
                DOUBLE_VALUES_FIELD_NUMBER: _ClassVar[int]
                STRING_VALUES_FIELD_NUMBER: _ClassVar[int]
                BYTE_VALUES_FIELD_NUMBER: _ClassVar[int]
                metadata: str
                bool_values: _containers.RepeatedScalarFieldContainer[bool]
                int_values: _containers.RepeatedScalarFieldContainer[int]
                long_values: _containers.RepeatedScalarFieldContainer[int]
                float_values: _containers.RepeatedScalarFieldContainer[float]
                double_values: _containers.RepeatedScalarFieldContainer[float]
                string_values: _containers.RepeatedScalarFieldContainer[str]
                byte_values: _containers.RepeatedScalarFieldContainer[bytes]
                def __init__(self, metadata: _Optional[str] = ..., bool_values: _Optional[_Iterable[bool]] = ..., int_values: _Optional[_Iterable[int]] = ..., long_values: _Optional[_Iterable[int]] = ..., float_values: _Optional[_Iterable[float]] = ..., double_values: _Optional[_Iterable[float]] = ..., string_values: _Optional[_Iterable[str]] = ..., byte_values: _Optional[_Iterable[bytes]] = ...) -> None: ...
            NAME_FIELD_NUMBER: _ClassVar[int]
            TYPE_FIELD_NUMBER: _ClassVar[int]
            IS_MANDATORY_FIELD_NUMBER: _ClassVar[int]
            IS_LIST_FIELD_NUMBER: _ClassVar[int]
            METADATA_FIELD_NUMBER: _ClassVar[int]
            VALUES_FIELD_NUMBER: _ClassVar[int]
            DEFAULT_FIELD_NUMBER: _ClassVar[int]
            NESTED_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
            name: str
            type: ModelData.AgentClass.Attribute.AttributeType
            is_mandatory: bool
            is_list: bool
            metadata: str
            values: _containers.RepeatedCompositeFieldContainer[ModelData.AgentClass.Attribute.ValueSet]
            default: ModelData.AgentClass.Attribute.ValueSet
            nested_attributes: _containers.RepeatedCompositeFieldContainer[ModelData.AgentClass.Attribute]
            def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[ModelData.AgentClass.Attribute.AttributeType, str]] = ..., is_mandatory: bool = ..., is_list: bool = ..., metadata: _Optional[str] = ..., values: _Optional[_Iterable[_Union[ModelData.AgentClass.Attribute.ValueSet, _Mapping]]] = ..., default: _Optional[_Union[ModelData.AgentClass.Attribute.ValueSet, _Mapping]] = ..., nested_attributes: _Optional[_Iterable[_Union[ModelData.AgentClass.Attribute, _Mapping]]] = ...) -> None: ...
        class Product(_message.Message):
            __slots__ = ("name", "metadata")
            NAME_FIELD_NUMBER: _ClassVar[int]
            METADATA_FIELD_NUMBER: _ClassVar[int]
            name: str
            metadata: str
            def __init__(self, name: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...
        class Output(_message.Message):
            __slots__ = ("name", "metadata")
            NAME_FIELD_NUMBER: _ClassVar[int]
            METADATA_FIELD_NUMBER: _ClassVar[int]
            name: str
            metadata: str
            def __init__(self, name: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...
        NAME_ALIAS_FIELD_NUMBER: _ClassVar[int]
        IMPORT_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
        LANGUAGE_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
        PRODUCTS_FIELD_NUMBER: _ClassVar[int]
        OUTPUTS_FIELD_NUMBER: _ClassVar[int]
        name_alias: str
        import_identifier: str
        language: ModelData.AgentClass.ImplementationLanguage
        metadata: str
        attributes: _containers.RepeatedCompositeFieldContainer[ModelData.AgentClass.Attribute]
        products: _containers.RepeatedCompositeFieldContainer[ModelData.AgentClass.Product]
        outputs: _containers.RepeatedCompositeFieldContainer[ModelData.AgentClass.Output]
        def __init__(self, name_alias: _Optional[str] = ..., import_identifier: _Optional[str] = ..., language: _Optional[_Union[ModelData.AgentClass.ImplementationLanguage, str]] = ..., metadata: _Optional[str] = ..., attributes: _Optional[_Iterable[_Union[ModelData.AgentClass.Attribute, _Mapping]]] = ..., products: _Optional[_Iterable[_Union[ModelData.AgentClass.Product, _Mapping]]] = ..., outputs: _Optional[_Iterable[_Union[ModelData.AgentClass.Output, _Mapping]]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_DEFINITION_FIELD_NUMBER: _ClassVar[int]
    AGENT_CLASSES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    package_definition: ModelData.JavaPackages
    agent_classes: _containers.RepeatedCompositeFieldContainer[ModelData.AgentClass]
    metadata: str
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., package_definition: _Optional[_Union[ModelData.JavaPackages, _Mapping]] = ..., agent_classes: _Optional[_Iterable[_Union[ModelData.AgentClass, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduledTime(_message.Message):
    __slots__ = ("time_step",)
    TIME_STEP_FIELD_NUMBER: _ClassVar[int]
    time_step: int
    def __init__(self, time_step: _Optional[int] = ...) -> None: ...

class WarmUpMessage(_message.Message):
    __slots__ = ("needed",)
    NEEDED_FIELD_NUMBER: _ClassVar[int]
    needed: bool
    def __init__(self, needed: bool = ...) -> None: ...

class Output(_message.Message):
    __slots__ = ("agent_types", "series")
    class AgentType(_message.Message):
        __slots__ = ("class_name", "fields")
        class Field(_message.Message):
            __slots__ = ("field_id", "field_name", "index_names")
            FIELD_ID_FIELD_NUMBER: _ClassVar[int]
            FIELD_NAME_FIELD_NUMBER: _ClassVar[int]
            INDEX_NAMES_FIELD_NUMBER: _ClassVar[int]
            field_id: int
            field_name: str
            index_names: _containers.RepeatedScalarFieldContainer[str]
            def __init__(self, field_id: _Optional[int] = ..., field_name: _Optional[str] = ..., index_names: _Optional[_Iterable[str]] = ...) -> None: ...
        CLASS_NAME_FIELD_NUMBER: _ClassVar[int]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        class_name: str
        fields: _containers.RepeatedCompositeFieldContainer[Output.AgentType.Field]
        def __init__(self, class_name: _Optional[str] = ..., fields: _Optional[_Iterable[_Union[Output.AgentType.Field, _Mapping]]] = ...) -> None: ...
    class Series(_message.Message):
        __slots__ = ("class_name", "agent_id", "lines")
        class Line(_message.Message):
            __slots__ = ("time_step", "columns")
            class Column(_message.Message):
                __slots__ = ("field_id", "value", "entries")
                class Map(_message.Message):
                    __slots__ = ("index_values", "value")
                    INDEX_VALUES_FIELD_NUMBER: _ClassVar[int]
                    VALUE_FIELD_NUMBER: _ClassVar[int]
                    index_values: _containers.RepeatedScalarFieldContainer[str]
                    value: str
                    def __init__(self, index_values: _Optional[_Iterable[str]] = ..., value: _Optional[str] = ...) -> None: ...
                FIELD_ID_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                ENTRIES_FIELD_NUMBER: _ClassVar[int]
                field_id: int
                value: float
                entries: _containers.RepeatedCompositeFieldContainer[Output.Series.Line.Column.Map]
                def __init__(self, field_id: _Optional[int] = ..., value: _Optional[float] = ..., entries: _Optional[_Iterable[_Union[Output.Series.Line.Column.Map, _Mapping]]] = ...) -> None: ...
            TIME_STEP_FIELD_NUMBER: _ClassVar[int]
            COLUMNS_FIELD_NUMBER: _ClassVar[int]
            time_step: int
            columns: _containers.RepeatedCompositeFieldContainer[Output.Series.Line.Column]
            def __init__(self, time_step: _Optional[int] = ..., columns: _Optional[_Iterable[_Union[Output.Series.Line.Column, _Mapping]]] = ...) -> None: ...
        CLASS_NAME_FIELD_NUMBER: _ClassVar[int]
        AGENT_ID_FIELD_NUMBER: _ClassVar[int]
        LINES_FIELD_NUMBER: _ClassVar[int]
        class_name: str
        agent_id: int
        lines: _containers.RepeatedCompositeFieldContainer[Output.Series.Line]
        def __init__(self, class_name: _Optional[str] = ..., agent_id: _Optional[int] = ..., lines: _Optional[_Iterable[_Union[Output.Series.Line, _Mapping]]] = ...) -> None: ...
    AGENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    SERIES_FIELD_NUMBER: _ClassVar[int]
    agent_types: _containers.RepeatedCompositeFieldContainer[Output.AgentType]
    series: _containers.RepeatedCompositeFieldContainer[Output.Series]
    def __init__(self, agent_types: _Optional[_Iterable[_Union[Output.AgentType, _Mapping]]] = ..., series: _Optional[_Iterable[_Union[Output.Series, _Mapping]]] = ...) -> None: ...

class AddressBook(_message.Message):
    __slots__ = ("process_id", "agent_ids")
    PROCESS_ID_FIELD_NUMBER: _ClassVar[int]
    AGENT_IDS_FIELD_NUMBER: _ClassVar[int]
    process_id: int
    agent_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, process_id: _Optional[int] = ..., agent_ids: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: execution_data.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65xecution_data.proto\x12\x08iobinary\"\xe0\x03\n\rExecutionData\x12\x39\n\x0cversion_data\x18\x01 \x01(\x0b\x32#.iobinary.ExecutionData.VersionData\x12\x36\n\nsimulation\x18\x02 \x01(\x0b\x32\".iobinary.ExecutionData.Simulation\x12\x43\n\rconfiguration\x18\x03 \x01(\x0b\x32,.iobinary.ExecutionData.ProcessConfiguration\x1aq\n\x0bVersionData\x12\x15\n\rfame_protobuf\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x61me_io\x18\x02 \x01(\t\x12\x11\n\tfame_core\x18\x03 \x01(\t\x12\x0e\n\x06python\x18\x04 \x01(\t\x12\x0b\n\x03jvm\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x1aG\n\nSimulation\x12\r\n\x05start\x18\x01 \x01(\t\x12\x16\n\x0e\x64uration_in_ms\x18\x02 \x01(\x03\x12\x12\n\ntick_count\x18\x03 \x01(\x03\x1a[\n\x14ProcessConfiguration\x12\x12\n\ncore_count\x18\x01 \x01(\x05\x12\x16\n\x0eoutput_process\x18\x02 \x01(\x05\x12\x17\n\x0foutput_interval\x18\x03 \x01(\x05\x42(\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\tExecution')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'execution_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\tExecution'
  _globals['_EXECUTIONDATA']._serialized_start=35
  _globals['_EXECUTIONDATA']._serialized_end=515
  _globals['_EXECUTIONDATA_VERSIONDATA']._serialized_start=236
  _globals['_EXECUTIONDATA_VERSIONDATA']._serialized_end=349
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_start=351
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_end=422
  _globals['_EXECUTIONDATA_PROCESSCONFIGURATION']._serialized_start=424
  _globals['_EXECUTIONDATA_PROCESSCONFIGURATION']._serialized_end=515
# @@protoc_insertion_point(module_scope)



from fameprotobuf import agent_message_pb2 as _agent_message_pb2
from fameprotobuf import services_pb2 as _services_pb2
from fameprotobuf import input_file_pb2 as _input_file_pb2
from fameprotobuf import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MpiMessage(_message.Message):
    __slots__ = ("scheduled_time", "warm_up", "address_book", "input", "output", "messages", "model")
    SCHEDULED_TIME_FIELD_NUMBER: _ClassVar[int]
    WARM_UP_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_BOOK_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    scheduled_time: _services_pb2.ScheduledTime
    warm_up: _services_pb2.WarmUpMessage
    address_book: _services_pb2.AddressBook
    input: _input_file_pb2.InputData
    output: _services_pb2.Output
    messages: _containers.RepeatedCompositeFieldContainer[_agent_message_pb2.ProtoMessage]
    model: _model_pb2.ModelData
    def __init__(self, scheduled_time: _Optional[_Union[_services_pb2.ScheduledTime, _Mapping]] = ..., warm_up: _Optional[_Union[_services_pb2.WarmUpMessage, _Mapping]] = ..., address_book: _Optional[_Union[_services_pb2.AddressBook, _Mapping]] = ..., input: _Optional[_Union[_input_file_pb2.InputData, _Mapping]] = ..., output: _Optional[_Union[_services_pb2.Output, _Mapping]] = ..., messages: _Optional[_Iterable[_Union[_agent_message_pb2.ProtoMessage, _Mapping]]] = ..., model: _Optional[_Union[_model_pb2.ModelData, _Mapping]] = ...) -> None: ...

class Bundle(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[MpiMessage]
    def __init__(self, messages: _Optional[_Iterable[_Union[MpiMessage, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bundle.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import agent_message_pb2 as agent__message__pb2
from fameprotobuf import services_pb2 as services__pb2
from fameprotobuf import input_file_pb2 as input__file__pb2
from fameprotobuf import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x62undle.proto\x12\x03mpi\x1a\x13\x61gent_message.proto\x1a\x0eservices.proto\x1a\x10input_file.proto\x1a\x0bmodel.proto\"\xc4\x02\n\nMpiMessage\x12\x34\n\x0escheduled_time\x18\x01 \x01(\x0b\x32\x1c.communication.ScheduledTime\x12-\n\x07warm_up\x18\x02 \x01(\x0b\x32\x1c.communication.WarmUpMessage\x12\x30\n\x0c\x61\x64\x64ress_book\x18\x03 \x01(\x0b\x32\x1a.communication.AddressBook\x12\"\n\x05input\x18\x04 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x05 \x01(\x0b\x32\x15.communication.Output\x12-\n\x08messages\x18\x06 \x03(\x0b\x32\x1b.communication.ProtoMessage\x12\x1f\n\x05model\x18\x08 \x01(\x0b\x32\x10.model.ModelDataJ\x04\x08\x07\x10\x08\"+\n\x06\x42undle\x12!\n\x08messages\x18\x01 \x03(\x0b\x32\x0f.mpi.MpiMessageB\"\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x03Mpi')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bundle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\003Mpi'
  _globals['_MPIMESSAGE']._serialized_start=90
  _globals['_MPIMESSAGE']._serialized_end=414
  _globals['_BUNDLE']._serialized_start=416
  _globals['_BUNDLE']._serialized_end=459
# @@protoc_insertion_point(module_scope)



from fameprotobuf import contract_pb2 as _contract_pb2
from fameprotobuf import field_pb2 as _field_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InputData(_message.Message):
    __slots__ = ("run_id", "simulation", "time_series", "agents", "contracts", "schema", "string_sets", "metadata")
    class SimulationParam(_message.Message):
        __slots__ = ("start_time", "stop_time", "random_seed")
        START_TIME_FIELD_NUMBER: _ClassVar[int]
        STOP_TIME_FIELD_NUMBER: _ClassVar[int]
        RANDOM_SEED_FIELD_NUMBER: _ClassVar[int]
        start_time: int
        stop_time: int
        random_seed: int
        def __init__(self, start_time: _Optional[int] = ..., stop_time: _Optional[int] = ..., random_seed: _Optional[int] = ...) -> None: ...
    class TimeSeriesDao(_message.Message):
        __slots__ = ("series_id", "series_name", "time_steps", "values")
        SERIES_ID_FIELD_NUMBER: _ClassVar[int]
        SERIES_NAME_FIELD_NUMBER: _ClassVar[int]
        TIME_STEPS_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        series_id: int
        series_name: str
        time_steps: _containers.RepeatedScalarFieldContainer[int]
        values: _containers.RepeatedScalarFieldContainer[float]
        def __init__(self, series_id: _Optional[int] = ..., series_name: _Optional[str] = ..., time_steps: _Optional[_Iterable[int]] = ..., values: _Optional[_Iterable[float]] = ...) -> None: ...
    class AgentDao(_message.Message):
        __slots__ = ("id", "class_name", "fields", "metadata")
        ID_FIELD_NUMBER: _ClassVar[int]
        CLASS_NAME_FIELD_NUMBER: _ClassVar[int]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        id: int
        class_name: str
        fields: _containers.RepeatedCompositeFieldContainer[_field_pb2.NestedField]
        metadata: str
        def __init__(self, id: _Optional[int] = ..., class_name: _Optional[str] = ..., fields: _Optional[_Iterable[_Union[_field_pb2.NestedField, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...
    class StringSetDao(_message.Message):
        __slots__ = ("name", "values", "metadata")
        class StringSetEntry(_message.Message):
            __slots__ = ("name", "metadata")
            NAME_FIELD_NUMBER: _ClassVar[int]
            METADATA_FIELD_NUMBER: _ClassVar[int]
            name: str
            metadata: str
            def __init__(self, name: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...
        NAME_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        METADATA_FIELD_NUMBER: _ClassVar[int]
        name: str
        values: _containers.RepeatedCompositeFieldContainer[InputData.StringSetDao.StringSetEntry]
        metadata: str
        def __init__(self, name: _Optional[str] = ..., values: _Optional[_Iterable[_Union[InputData.StringSetDao.StringSetEntry, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    SIMULATION_FIELD_NUMBER: _ClassVar[int]
    TIME_SERIES_FIELD_NUMBER: _ClassVar[int]
    AGENTS_FIELD_NUMBER: _ClassVar[int]
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    STRING_SETS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    run_id: int
    simulation: InputData.SimulationParam
    time_series: _containers.RepeatedCompositeFieldContainer[InputData.TimeSeriesDao]
    agents: _containers.RepeatedCompositeFieldContainer[InputData.AgentDao]
    contracts: _containers.RepeatedCompositeFieldContainer[_contract_pb2.ProtoContract]
    schema: str
    string_sets: _containers.RepeatedCompositeFieldContainer[InputData.StringSetDao]
    metadata: str
    def __init__(self, run_id: _Optional[int] = ..., simulation: _Optional[_Union[InputData.SimulationParam, _Mapping]] = ..., time_series: _Optional[_Iterable[_Union[InputData.TimeSeriesDao, _Mapping]]] = ..., agents: _Optional[_Iterable[_Union[InputData.AgentDao, _Mapping]]] = ..., contracts: _Optional[_Iterable[_Union[_contract_pb2.ProtoContract, _Mapping]]] = ..., schema: _Optional[str] = ..., string_sets: _Optional[_Iterable[_Union[InputData.StringSetDao, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x05model\"\x93\x0b\n\tModelData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x39\n\x12package_definition\x18\x03 \x01(\x0b\x32\x1d.model.ModelData.JavaPackages\x12\x32\n\ragent_classes\x18\x04 \x03(\x0b\x32\x1b.model.ModelData.AgentClass\x12\x10\n\x08metadata\x18\x05 \x01(\t\x1a\x45\n\x0cJavaPackages\x12\x0e\n\x06\x61gents\x18\x01 \x03(\t\x12\x12\n\ndata_items\x18\x02 \x03(\t\x12\x11\n\tportables\x18\x03 \x03(\t\x1a\x9e\t\n\nAgentClass\x12\x12\n\nname_alias\x18\x01 \x02(\t\x12\x19\n\x11import_identifier\x18\x02 \x02(\t\x12\x44\n\x08language\x18\x03 \x02(\x0e\x32\x32.model.ModelData.AgentClass.ImplementationLanguage\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\x39\n\nattributes\x18\x05 \x03(\x0b\x32%.model.ModelData.AgentClass.Attribute\x12\x35\n\x08products\x18\x06 \x03(\x0b\x32#.model.ModelData.AgentClass.Product\x12\x33\n\x07outputs\x18\x07 \x03(\x0b\x32\".model.ModelData.AgentClass.Output\x1a\xc2\x05\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x41\n\x04type\x18\x02 \x02(\x0e\x32\x33.model.ModelData.AgentClass.Attribute.AttributeType\x12\x14\n\x0cis_mandatory\x18\x03 \x02(\x08\x12\x0f\n\x07is_list\x18\x04 \x02(\x08\x12\x10\n\x08metadata\x18\x05 \x01(\t\x12>\n\x06values\x18\x06 \x03(\x0b\x32..model.ModelData.AgentClass.Attribute.ValueSet\x12?\n\x07\x64\x65\x66\x61ult\x18\x07 \x01(\x0b\x32..model.ModelData.AgentClass.Attribute.ValueSet\x12@\n\x11nested_attributes\x18\x08 \x03(\x0b\x32%.model.ModelData.AgentClass.Attribute\x1a\xb3\x01\n\x08ValueSet\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x13\n\x0b\x62ool_values\x18\x02 \x03(\x08\x12\x12\n\nint_values\x18\x03 \x03(\x11\x12\x13\n\x0blong_values\x18\x04 \x03(\x12\x12\x14\n\x0c\x66loat_values\x18\x05 \x03(\x02\x12\x15\n\rdouble_values\x18\x06 \x03(\x01\x12\x15\n\rstring_values\x18\x07 \x03(\t\x12\x13\n\x0b\x62yte_values\x18\x08 \x03(\x0c\"\xb1\x01\n\rAttributeType\x12\x1e\n\x1a\x41TTRIBUTE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\x0b\n\x07INTEGER\x10\x02\x12\x08\n\x04LONG\x10\x03\x12\x0e\n\nTIME_STAMP\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\n\n\x06STRING\x10\x06\x12\x0e\n\nSTRING_SET\x10\x07\x12\x08\n\x04\x45NUM\x10\x08\x12\x0f\n\x0bTIME_SERIES\x10\t\x12\t\n\x05\x42LOCK\x10\n\x1a)\n\x07Product\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x1a(\n\x06Output\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\"H\n\x16ImplementationLanguage\x12\x18\n\x14LANGUAGE_UNSPECIFIED\x10\x00\x12\x08\n\x04JAVA\x10\x01\x12\n\n\x06PYTHON\x10\x02\x42$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Model')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Model'
  _globals['_MODELDATA']._serialized_start=23
  _globals['_MODELDATA']._serialized_end=1450
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_start=196
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_end=265
  _globals['_MODELDATA_AGENTCLASS']._serialized_start=268
  _globals['_MODELDATA_AGENTCLASS']._serialized_end=1450
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE']._serialized_start=585
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE']._serialized_end=1291
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_VALUESET']._serialized_start=932
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_VALUESET']._serialized_end=1111
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_ATTRIBUTETYPE']._serialized_start=1114
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_ATTRIBUTETYPE']._serialized_end=1291
  _globals['_MODELDATA_AGENTCLASS_PRODUCT']._serialized_start=1293
  _globals['_MODELDATA_AGENTCLASS_PRODUCT']._serialized_end=1334
  _globals['_MODELDATA_AGENTCLASS_OUTPUT']._serialized_start=1336
  _globals['_MODELDATA_AGENTCLASS_OUTPUT']._serialized_end=1376
  _globals['_MODELDATA_AGENTCLASS_IMPLEMENTATIONLANGUAGE']._serialized_start=1378
  _globals['_MODELDATA_AGENTCLASS_IMPLEMENTATIONLANGUAGE']._serialized_end=1450
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionData(_message.Message):
    __slots__ = ("version_data", "simulation", "configuration")
    class VersionData(_message.Message):
        __slots__ = ("fame_protobuf", "fame_io", "fame_core", "python", "jvm", "os")
        FAME_PROTOBUF_FIELD_NUMBER: _ClassVar[int]
        FAME_IO_FIELD_NUMBER: _ClassVar[int]
        FAME_CORE_FIELD_NUMBER: _ClassVar[int]
        PYTHON_FIELD_NUMBER: _ClassVar[int]
        JVM_FIELD_NUMBER: _ClassVar[int]
        OS_FIELD_NUMBER: _ClassVar[int]
        fame_protobuf: str
        fame_io: str
        fame_core: str
        python: str
        jvm: str
        os: str
        def __init__(self, fame_protobuf: _Optional[str] = ..., fame_io: _Optional[str] = ..., fame_core: _Optional[str] = ..., python: _Optional[str] = ..., jvm: _Optional[str] = ..., os: _Optional[str] = ...) -> None: ...
    class Simulation(_message.Message):
        __slots__ = ("start", "duration_in_ms", "tick_count")
        START_FIELD_NUMBER: _ClassVar[int]
        DURATION_IN_MS_FIELD_NUMBER: _ClassVar[int]
        TICK_COUNT_FIELD_NUMBER: _ClassVar[int]
        start: str
        duration_in_ms: int
        tick_count: int
        def __init__(self, start: _Optional[str] = ..., duration_in_ms: _Optional[int] = ..., tick_count: _Optional[int] = ...) -> None: ...
    class ProcessConfiguration(_message.Message):
        __slots__ = ("core_count", "output_process", "output_interval")
        CORE_COUNT_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_PROCESS_FIELD_NUMBER: _ClassVar[int]
        OUTPUT_INTERVAL_FIELD_NUMBER: _ClassVar[int]
        core_count: int
        output_process: int
        output_interval: int
        def __init__(self, core_count: _Optional[int] = ..., output_process: _Optional[int] = ..., output_interval: _Optional[int] = ...) -> None: ...
    VERSION_DATA_FIELD_NUMBER: _ClassVar[int]
    SIMULATION_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    version_data: ExecutionData.VersionData
    simulation: ExecutionData.Simulation
    configuration: ExecutionData.ProcessConfiguration
    def __init__(self, version_data: _Optional[_Union[ExecutionData.VersionData, _Mapping]] = ..., simulation: _Optional[_Union[ExecutionData.Simulation, _Mapping]] = ..., configuration: _Optional[_Union[ExecutionData.ProcessConfiguration, _Mapping]] = ...) -> None: ...
